/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.entity;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Set;

import mir.storage.Database;
import mir.storage.store.StorableObject;
import mir.storage.store.StoreIdentifier;


public class StorableObjectEntity extends AbstractEntity
		implements StorableObject {

  /**
   *  Method:       getStoreIdentifier
   *  Description:  returns unique StoreIdentifer under which the Entity
   *                is Stored. Based upon primary key and tablename.
   *
   *  @return       StoreIdentifier
   */
  public StoreIdentifier getStoreIdentifier() {
    String id = getId();
    if ( id!=null && database!= null )
     return new StoreIdentifier(this, id+"@"+database.getTableName());
    return null;
  }

  public static final StoreIdentifier getStoreIdentifier(
     Class theEntityClass, String theTable, String id) {
     if (id == null) {
        return null;
     }
		return new StoreIdentifier(theEntityClass, id + "@" + theTable);
  }

  public static final StoreIdentifier getStoreIdentifier(Database theStorage,
     Class theEntityClass, ResultSet rs) throws SQLException {

        String idcol = theStorage.getIdFieldName();
        String idval = rs.getObject(idcol).toString();

        if (idval != null) {
           return getStoreIdentifier(theEntityClass,
              theStorage.getTableName(), idval);
        }

     return null;
  }

  /**
   *  Method:       getNotifyOnReleaseSet()
   *  Description:  returns empty Set, GenericContainer does not implement
   *                dependencies.
   *
   *  @return       null
   */
  public Set getNotifyOnReleaseSet() { return null; }

}