package mir.util.xml.html;

import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import mir.util.xml.XMLName;
import mir.util.xml.XMLParserEngine;
import mir.util.xml.XMLParserExc;
import mir.util.xml.XMLParserFailure;
import mir.util.xml.XMLReaderTool;

/**
 */

public class XMLHTMLParserProvider implements XMLParserEngine.XMLParserProvider {
  public XMLHTMLParserProvider() {
  }

  public void parse(java.io.Reader aReader, final XMLParserEngine.XMLParserReceiver aReceiver) throws XMLParserExc, XMLParserFailure {
    HTMLParser parser = new HTMLParser();

    try {
      aReceiver.startDocument();

      parser.parse(aReader, new HTMLParser.ParserReceiver() {
        public void dtd(String aDTD) throws HTMLParserExc {
          try {
            aReceiver.extra(aDTD);
          }
          catch (XMLParserExc t) {
            throw new HTMLParserFailure(t);
          }
        }

        public void openTag(String aTag, Map anAttributes) {
          Map attributes = new HashMap();
          Iterator i = anAttributes.entrySet().iterator();

          while (i.hasNext()) {
            Map.Entry entry = (Map.Entry) i.next();
            XMLName key = XMLReaderTool.getXMLNameForQualifiedName((String) entry.getKey());
            String value = (String) entry.getValue();
            if (value==null)
              value = key.getLocalName();

            attributes.put(key, value);
          }

          try {
            aReceiver.startElement(XMLReaderTool.getXMLNameForQualifiedName(aTag), attributes);
          }
          catch (XMLParserExc e) {
            throw new HTMLParserFailure(e);
          }
        }

        public void closeTag(String aTag) {
          try {
            aReceiver.endElement(XMLReaderTool.getXMLNameForQualifiedName(aTag));
          }
          catch (XMLParserExc e) {
            throw new HTMLParserFailure(e);
          }
        }

        public void comment(String aData) {
          try {
            aReceiver.extra("<!--"+aData+"-->");
          }
          catch (XMLParserExc e) {
            throw new HTMLParserFailure(e);
          }
        }

        public void cdata(String aData) {
          try {
            aReceiver.text(aData);
          }
          catch (XMLParserExc e) {
            throw new HTMLParserFailure(e);
          }
        }
      });

      aReceiver.endDocument();
    }
    catch (IOException e) {
      throw new XMLParserFailure(e);
    }
    catch (HTMLParserExc e) {
      throw new XMLParserFailure(e);
    }
  }
}
